@@ -26,7 +26,7 @@ class ClusterRoleBinding(Resource):
         self.cluster_role = cluster_role
         self.subjects = subjects
 
-    def to_dict(self):
+    def to_dict(self) -> None:
         super().to_dict()
         if not self.yaml_file:
             if not self.cluster_role:
