@@ -37,7 +37,7 @@ class MultiNetworkPolicy(NamespacedResource):
         self.ingress = ingress
         self.egress = egress
 
-    def to_dict(self):
+    def to_dict(self) -> None:
         super().to_dict()
         if not self.yaml_file:
             if not self.network_name and self.pod_selector is None:
