@@ -31,9 +31,7 @@ class SealedSecret(NamespacedResource):
         self.template = template
         self.data = data
 
-    def to_dict(self):
-        self.res: Dict[str, Any]
-
+    def to_dict(self) -> None:
         super().to_dict()
 
         if not self.yaml_file:
